Contributing
************

If you have any questions, comments, bug fixes or improvement suggestions, feel
free to contact us via our `GitHub`_ page. Before contributing, be sure to read
the `contributing guidelines`_.

.. _GitHub: https://github.com/datalad/datalad-catalog
.. _contributing guidelines: https://github.com/datalad/datalad-catalog#7-contributing
